==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/outputs/InMageRcmNicDetailsResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * InMageRcm NIC details.
 * @property isPrimaryNic A value indicating whether this is the primary NIC.
 * @property isSelectedForFailover A value indicating whether this NIC is selected for failover.
 * @property nicId The NIC Id.
 * @property sourceIPAddress The source IP address.
 * @property sourceIPAddressType The source IP address type.
 * @property sourceNetworkId Source network Id.
 * @property sourceSubnetName Source subnet name.
 * @property targetIPAddress The target IP address.
 * @property targetIPAddressType The target IP address type.
 * @property targetSubnetName Target subnet name.
 * @property testIPAddress The test IP address.
 * @property testIPAddressType The test IP address type.
 * @property testSubnetName Test subnet name.
 */
public data class InMageRcmNicDetailsResponse(
    public val isPrimaryNic: String? = null,
    public val isSelectedForFailover: String? = null,
    public val nicId: String,
    public val sourceIPAddress: String,
    public val sourceIPAddressType: String,
    public val sourceNetworkId: String,
    public val sourceSubnetName: String,
    public val targetIPAddress: String? = null,
    public val targetIPAddressType: String? = null,
    public val targetSubnetName: String? = null,
    public val testIPAddress: String? = null,
    public val testIPAddressType: String? = null,
    public val testSubnetName: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.recoveryservices.outputs.InMageRcmNicDetailsResponse):
            InMageRcmNicDetailsResponse = InMageRcmNicDetailsResponse(
            isPrimaryNic = javaType.isPrimaryNic().map({ args0 -> args0 }).orElse(null),
            isSelectedForFailover = javaType.isSelectedForFailover().map({ args0 -> args0 }).orElse(null),
            nicId = javaType.nicId(),
            sourceIPAddress = javaType.sourceIPAddress(),
            sourceIPAddressType = javaType.sourceIPAddressType(),
            sourceNetworkId = javaType.sourceNetworkId(),
            sourceSubnetName = javaType.sourceSubnetName(),
            targetIPAddress = javaType.targetIPAddress().map({ args0 -> args0 }).orElse(null),
            targetIPAddressType = javaType.targetIPAddressType().map({ args0 -> args0 }).orElse(null),
            targetSubnetName = javaType.targetSubnetName().map({ args0 -> args0 }).orElse(null),
            testIPAddress = javaType.testIPAddress().map({ args0 -> args0 }).orElse(null),
            testIPAddressType = javaType.testIPAddressType().map({ args0 -> args0 }).orElse(null),
            testSubnetName = javaType.testSubnetName().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/outputs/InMageRcmNicDetailsResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * InMageRcm NIC details.
 * @property isPrimaryNic A value indicating whether this is the primary NIC.
 * @property isSelectedForFailover A value indicating whether this NIC is selected for failover.
 * @property nicId The NIC Id.
 * @property sourceIPAddress The source IP address.
 * @property sourceIPAddressType The source IP address type.
 * @property sourceNetworkId Source network Id.
 * @property sourceSubnetName Source subnet name.
 * @property targetIPAddress The target IP address.
 * @property targetIPAddressType The target IP address type.
 * @property targetSubnetName Target subnet name.
 * @property testIPAddress The test IP address.
 * @property testIPAddressType The test IP address type.
 * @property testSubnetName Test subnet name.
 */
public data class InMageRcmNicDetailsResponse(
    public val isPrimaryNic: String? = null,
    public val isSelectedForFailover: String? = null,
    public val nicId: String,
    public val sourceIPAddress: String,
    public val sourceIPAddressType: String,
    public val sourceNetworkId: String,
    public val sourceSubnetName: String,
    public val targetIPAddress: String? = null,
    public val targetIPAddressType: String? = null,
    public val targetSubnetName: String? = null,
    public val testIPAddress: String? = null,
    public val testIPAddressType: String? = null,
    public val testSubnetName: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.recoveryservices.outputs.InMageRcmNicDetailsResponse): InMageRcmNicDetailsResponse = InMageRcmNicDetailsResponse(
            isPrimaryNic = javaType.isPrimaryNic().map({ args0 -> args0 }).orElse(null),
            isSelectedForFailover = javaType.isSelectedForFailover().map({ args0 -> args0 }).orElse(null),
            nicId = javaType.nicId(),
            sourceIPAddress = javaType.sourceIPAddress(),
            sourceIPAddressType = javaType.sourceIPAddressType(),
            sourceNetworkId = javaType.sourceNetworkId(),
            sourceSubnetName = javaType.sourceSubnetName(),
            targetIPAddress = javaType.targetIPAddress().map({ args0 -> args0 }).orElse(null),
            targetIPAddressType = javaType.targetIPAddressType().map({ args0 -> args0 }).orElse(null),
            targetSubnetName = javaType.targetSubnetName().map({ args0 -> args0 }).orElse(null),
            testIPAddress = javaType.testIPAddress().map({ args0 -> args0 }).orElse(null),
            testIPAddressType = javaType.testIPAddressType().map({ args0 -> args0 }).orElse(null),
            testSubnetName = javaType.testSubnetName().map({ args0 -> args0 }).orElse(null),
        )
    }
}
